[SCM] WebKit Debian packaging branch, webkit-1.2, updated. upstream/1.1.90-6072-g9a69373

bdakin at apple.com bdakin at apple.com
Thu Apr 8 01:02:36 UTC 2010


The following commit has been merged in the webkit-1.2 branch:
commit f55e62f7ac0c5292dfafd11d0982601f15f11cf3
Author: bdakin at apple.com <bdakin at apple.com@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Tue Jan 12 20:54:30 2010 +0000

    WebCore: Rubber-stamped by Dave Hyatt.
    
    This patch changes the name of -webkit-shadow to -webkit-svg-shadow
    to avoid giving a custom property an overly-general name.
    <rdar://problem/7534590>
    
    * css/CSSComputedStyleDeclaration.cpp:
    (WebCore::):
    * css/CSSParser.cpp:
    (WebCore::CSSParser::parseShadow):
    * css/SVGCSSComputedStyleDeclaration.cpp:
    (WebCore::CSSComputedStyleDeclaration::getSVGPropertyCSSValue):
    * css/SVGCSSParser.cpp:
    (WebCore::CSSParser::parseSVGValue):
    * css/SVGCSSPropertyNames.in:
    * css/SVGCSSStyleSelector.cpp:
    (WebCore::CSSStyleSelector::applySVGProperty):
    
    LayoutTests: This patch changes the name of -webkit-shadow to -webkit-svg-shadow
    to avoid giving a custom property an overly-general name.
    <rdar://problem/7534590>
    
    * fast/repaint/moving-shadow-on-container.html:
    * fast/repaint/moving-shadow-on-path.html:
    * platform/gtk/svg/css/getComputedStyle-basic-expected.txt:
    * platform/mac/fast/css/getComputedStyle/computed-style-expected.txt:
    * platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt:
    * platform/win/fast/css/getComputedStyle/computed-style-expected.txt:
    * platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt:
    * svg/css/arrow-with-shadow.svg:
    * svg/css/circle-in-mask-with-shadow.svg:
    * svg/css/clippath-with-shadow.svg:
    * svg/css/composite-shadow-example.html:
    * svg/css/composite-shadow-with-opacity.html:
    * svg/css/getComputedStyle-basic-expected.txt:
    * svg/css/group-with-shadow.svg:
    * svg/css/mask-with-shadow.svg:
    * svg/css/path-with-shadow.svg:
    * svg/css/shadow-with-large-radius.svg:
    * svg/css/shadow-with-negative-offset.svg:
    * svg/css/stars-with-shadow.html:
    * svg/filters/shadow-on-filter.svg:
    * svg/filters/shadow-on-rect-with-filter.svg:
    
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@53157 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/LayoutTests/ChangeLog b/LayoutTests/ChangeLog
index f9c3472..ac26414 100644
--- a/LayoutTests/ChangeLog
+++ b/LayoutTests/ChangeLog
@@ -1,3 +1,31 @@
+2010-01-12  Beth Dakin  <bdakin at apple.com>
+
+        This patch changes the name of -webkit-shadow to -webkit-svg-shadow 
+        to avoid giving a custom property an overly-general name.
+        <rdar://problem/7534590>
+
+        * fast/repaint/moving-shadow-on-container.html:
+        * fast/repaint/moving-shadow-on-path.html:
+        * platform/gtk/svg/css/getComputedStyle-basic-expected.txt:
+        * platform/mac/fast/css/getComputedStyle/computed-style-expected.txt:
+        * platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt:
+        * platform/win/fast/css/getComputedStyle/computed-style-expected.txt:
+        * platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt:
+        * svg/css/arrow-with-shadow.svg:
+        * svg/css/circle-in-mask-with-shadow.svg:
+        * svg/css/clippath-with-shadow.svg:
+        * svg/css/composite-shadow-example.html:
+        * svg/css/composite-shadow-with-opacity.html:
+        * svg/css/getComputedStyle-basic-expected.txt:
+        * svg/css/group-with-shadow.svg:
+        * svg/css/mask-with-shadow.svg:
+        * svg/css/path-with-shadow.svg:
+        * svg/css/shadow-with-large-radius.svg:
+        * svg/css/shadow-with-negative-offset.svg:
+        * svg/css/stars-with-shadow.html:
+        * svg/filters/shadow-on-filter.svg:
+        * svg/filters/shadow-on-rect-with-filter.svg:
+
 2010-01-12  Eric Carlson  <eric.carlson at apple.com>
 
         Unreviewed, build fix.
diff --git a/LayoutTests/fast/repaint/moving-shadow-on-container.html b/LayoutTests/fast/repaint/moving-shadow-on-container.html
index 26d4394..0a0b175 100644
--- a/LayoutTests/fast/repaint/moving-shadow-on-container.html
+++ b/LayoutTests/fast/repaint/moving-shadow-on-container.html
@@ -53,7 +53,7 @@ window.addEventListener('load', function () {
         { pos: [ 250, 100 ], size: 60, hasStroke: true },
         { pos: [ 400, 100 ], size: 50, hasStroke: true }
     ];
-    svgContainer.style.WebkitShadow = '5px 5px 5px red';
+    svgContainer.style.WebkitSvgShadow = '5px 5px 5px red';
     for (var i = 0; i < shapes.length; ++i) {
         var shape = shapes[i];
         var node = newSvgElement('path', svgContainer, {
diff --git a/LayoutTests/fast/repaint/moving-shadow-on-path.html b/LayoutTests/fast/repaint/moving-shadow-on-path.html
index 346d03c..77c563e 100644
--- a/LayoutTests/fast/repaint/moving-shadow-on-path.html
+++ b/LayoutTests/fast/repaint/moving-shadow-on-path.html
@@ -61,7 +61,7 @@ window.addEventListener('load', function () {
             stroke: 'black',
             'stroke-width': 10,
         });
-        node.style.WebkitShadow = '5px 5px 5px red';
+        node.style.WebkitSvgShadow = '5px 5px 5px red';
         if (i == 0)
             node.id = "first-star";
         setCenterPosition(node, shape.pos[0], shape.pos[1]);
diff --git a/LayoutTests/platform/gtk/svg/css/getComputedStyle-basic-expected.txt b/LayoutTests/platform/gtk/svg/css/getComputedStyle-basic-expected.txt
index f82e8c7..08a90bd 100644
--- a/LayoutTests/platform/gtk/svg/css/getComputedStyle-basic-expected.txt
+++ b/LayoutTests/platform/gtk/svg/css/getComputedStyle-basic-expected.txt
@@ -408,8 +408,8 @@ rect: style.getPropertyValue(glyph-orientation-horizontal) : 0deg
 rect: style.getPropertyCSSValue(glyph-orientation-horizontal) : [object CSSPrimitiveValue]
 rect: style.getPropertyValue(glyph-orientation-vertical) : auto
 rect: style.getPropertyCSSValue(glyph-orientation-vertical) : [object CSSPrimitiveValue]
-rect: style.getPropertyValue(-webkit-shadow) : none
-rect: style.getPropertyCSSValue(-webkit-shadow) : [object CSSPrimitiveValue]
+rect: style.getPropertyValue(-webkit-svg-shadow) : none
+rect: style.getPropertyCSSValue(-webkit-svg-shadow) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(background-attachment) : scroll
 g: style.getPropertyCSSValue(background-attachment) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(background-clip) : border-box
@@ -820,6 +820,6 @@ g: style.getPropertyValue(glyph-orientation-horizontal) : 0deg
 g: style.getPropertyCSSValue(glyph-orientation-horizontal) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(glyph-orientation-vertical) : auto
 g: style.getPropertyCSSValue(glyph-orientation-vertical) : [object CSSPrimitiveValue]
-g: style.getPropertyValue(-webkit-shadow) : none
-g: style.getPropertyCSSValue(-webkit-shadow) : [object CSSPrimitiveValue]
+g: style.getPropertyValue(-webkit-svg-shadow) : none
+g: style.getPropertyCSSValue(-webkit-svg-shadow) : [object CSSPrimitiveValue]
 
diff --git a/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-expected.txt b/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-expected.txt
index ed29dc9..ff486e5 100644
--- a/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-expected.txt
+++ b/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-expected.txt
@@ -206,7 +206,7 @@ text-anchor: start;
 writing-mode: lr-tb;
 glyph-orientation-horizontal: 0deg;
 glyph-orientation-vertical: auto;
--webkit-shadow: none;
+-webkit-svg-shadow: none;
 
 Other attributes that the computed style class supports:
 
diff --git a/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt b/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
index 8328936..c1291a1 100644
--- a/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
+++ b/LayoutTests/platform/mac/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
@@ -205,7 +205,7 @@ Computed style of an element whose parent's 'display' value is 'none':
     writing-mode: lr-tb
     glyph-orientation-horizontal: 0deg
     glyph-orientation-vertical: auto
-    -webkit-shadow: none
+    -webkit-svg-shadow: none
     background-position-x: 0%
     background-position-y: 0%
     border-spacing: 0px 0px
diff --git a/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-expected.txt b/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-expected.txt
index 681cbf4..5ab7618 100644
--- a/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-expected.txt
+++ b/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-expected.txt
@@ -205,7 +205,7 @@ text-anchor: start;
 writing-mode: lr-tb;
 glyph-orientation-horizontal: 0deg;
 glyph-orientation-vertical: auto;
--webkit-shadow: none;
+-webkit-svg-shadow: none;
 
 Other attributes that the computed style class supports:
 
diff --git a/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt b/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
index 36f2f4c..18051fa 100644
--- a/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
+++ b/LayoutTests/platform/win/fast/css/getComputedStyle/computed-style-without-renderer-expected.txt
@@ -204,7 +204,7 @@ Computed style of an element whose parent's 'display' value is 'none':
     writing-mode: lr-tb
     glyph-orientation-horizontal: 0deg
     glyph-orientation-vertical: auto
-    -webkit-shadow: none
+    -webkit-svg-shadow: none
     background-position-x: 0%
     background-position-y: 0%
     border-spacing: 0px 0px
diff --git a/LayoutTests/svg/css/arrow-with-shadow.svg b/LayoutTests/svg/css/arrow-with-shadow.svg
index 1cb9b5c..e4a3fae 100644
--- a/LayoutTests/svg/css/arrow-with-shadow.svg
+++ b/LayoutTests/svg/css/arrow-with-shadow.svg
@@ -4,7 +4,7 @@
 <svg version="1.1" baseProfile="basic" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="svg-root" width="100%" height="100%" viewBox="0 0 480 360">
 
 	<desc id="test-desc">Shadowy Arrow</desc>
-	<g id="test-body-content" transform="scale(2)" style="-webkit-shadow: 5px 5px 5px grey">
+	<g id="test-body-content" transform="scale(2)" style="-webkit-svg-shadow: 5px 5px 5px grey">
 		<a xlink:href="resources/link-target.html">
 			<path fill="none" stroke-width="20" stroke="blue" d="M 185,40 h -100 v -12 l -45 36 l 45 36 v -12 h 100 z"/>
 		</a>
diff --git a/LayoutTests/svg/css/circle-in-mask-with-shadow.svg b/LayoutTests/svg/css/circle-in-mask-with-shadow.svg
index 8a2c72c..1ce9a02 100644
--- a/LayoutTests/svg/css/circle-in-mask-with-shadow.svg
+++ b/LayoutTests/svg/css/circle-in-mask-with-shadow.svg
@@ -18,10 +18,10 @@
         <rect id="masked" width="300" height="300" fill="url(#maskedGradient)" />
 
         <mask id="mask_1">
-            <circle cx="55" cy="55" r="50" fill="#ffffff" style="-webkit-shadow:5px 5px 5px red" />
-            <circle cx="55" cy="165" r="50" fill="#ffffff" style="-webkit-shadow:5px 5px 5px red" />
-            <circle cx="165" cy="55" r="50" fill="#ffffff" style="-webkit-shadow:5px 5px 5px red" />
-            <circle cx="165" cy="165" r="50" fill="#ffffff" style="-webkit-shadow:5px 5px 5px red" />
+            <circle cx="55" cy="55" r="50" fill="#ffffff" style="-webkit-svg-shadow:5px 5px 5px red" />
+            <circle cx="55" cy="165" r="50" fill="#ffffff" style="-webkit-svg-shadow:5px 5px 5px red" />
+            <circle cx="165" cy="55" r="50" fill="#ffffff" style="-webkit-svg-shadow:5px 5px 5px red" />
+            <circle cx="165" cy="165" r="50" fill="#ffffff" style="-webkit-svg-shadow:5px 5px 5px red" />
         </mask>
 
      
diff --git a/LayoutTests/svg/css/clippath-with-shadow.svg b/LayoutTests/svg/css/clippath-with-shadow.svg
index bc80d67..418d1a2 100644
--- a/LayoutTests/svg/css/clippath-with-shadow.svg
+++ b/LayoutTests/svg/css/clippath-with-shadow.svg
@@ -6,6 +6,6 @@
    version="1.0">
   <rect fill="red" x="0" y="0" width="200" height="200" />
   <rect x="200" y="0" fill="none" width="200" height="200" transform="translate(-200,0)" id="crect" />
-  <clipPath id="clip" style="-webkit-shadow: 5px 5px 5px grey"><use xlink:href="#crect" /></clipPath>
+  <clipPath id="clip" style="-webkit-svg-shadow: 5px 5px 5px grey"><use xlink:href="#crect" /></clipPath>
   <rect fill="green" stroke="none" x="0" y="0" width="400" height="200" clip-path="url(#clip)" />
 </svg>
diff --git a/LayoutTests/svg/css/composite-shadow-example.html b/LayoutTests/svg/css/composite-shadow-example.html
index d6373b7..e9f301b 100644
--- a/LayoutTests/svg/css/composite-shadow-example.html
+++ b/LayoutTests/svg/css/composite-shadow-example.html
@@ -47,7 +47,7 @@ window.addEventListener('load', function () {
         { pos: [ 250, 100 ], size: 60, hasStroke: true },
         { pos: [ 400, 100 ], size: 50, hasStroke: true }
     ];
-    svgContainer.style.WebkitShadow = '5px 5px 5px red';
+    svgContainer.style.WebkitSvgShadow = '5px 5px 5px red';
     for (var i = 0; i < shapes.length; ++i) {
         var shape = shapes[i];
         var group = newSvgElement('g', svgContainer);
diff --git a/LayoutTests/svg/css/composite-shadow-with-opacity.html b/LayoutTests/svg/css/composite-shadow-with-opacity.html
index 8db2102..885ac0b 100644
--- a/LayoutTests/svg/css/composite-shadow-with-opacity.html
+++ b/LayoutTests/svg/css/composite-shadow-with-opacity.html
@@ -47,7 +47,7 @@ window.addEventListener('load', function () {
         { pos: [ 250, 100 ], size: 60, hasStroke: true },
         { pos: [ 400, 100 ], size: 50, hasStroke: true }
     ];
-    svgContainer.style.WebkitShadow = '5px 5px 5px red';
+    svgContainer.style.WebkitSvgShadow = '5px 5px 5px red';
     svgContainer.style.opacity = '0.5';
     for (var i = 0; i < shapes.length; ++i) {
         var shape = shapes[i];
diff --git a/LayoutTests/svg/css/getComputedStyle-basic-expected.txt b/LayoutTests/svg/css/getComputedStyle-basic-expected.txt
index 439b215..bb8c0b3 100644
--- a/LayoutTests/svg/css/getComputedStyle-basic-expected.txt
+++ b/LayoutTests/svg/css/getComputedStyle-basic-expected.txt
@@ -410,8 +410,8 @@ rect: style.getPropertyValue(glyph-orientation-horizontal) : 0deg
 rect: style.getPropertyCSSValue(glyph-orientation-horizontal) : [object CSSPrimitiveValue]
 rect: style.getPropertyValue(glyph-orientation-vertical) : auto
 rect: style.getPropertyCSSValue(glyph-orientation-vertical) : [object CSSPrimitiveValue]
-rect: style.getPropertyValue(-webkit-shadow) : none
-rect: style.getPropertyCSSValue(-webkit-shadow) : [object CSSPrimitiveValue]
+rect: style.getPropertyValue(-webkit-svg-shadow) : none
+rect: style.getPropertyCSSValue(-webkit-svg-shadow) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(background-attachment) : scroll
 g: style.getPropertyCSSValue(background-attachment) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(background-clip) : border-box
@@ -824,6 +824,6 @@ g: style.getPropertyValue(glyph-orientation-horizontal) : 0deg
 g: style.getPropertyCSSValue(glyph-orientation-horizontal) : [object CSSPrimitiveValue]
 g: style.getPropertyValue(glyph-orientation-vertical) : auto
 g: style.getPropertyCSSValue(glyph-orientation-vertical) : [object CSSPrimitiveValue]
-g: style.getPropertyValue(-webkit-shadow) : none
-g: style.getPropertyCSSValue(-webkit-shadow) : [object CSSPrimitiveValue]
+g: style.getPropertyValue(-webkit-svg-shadow) : none
+g: style.getPropertyCSSValue(-webkit-svg-shadow) : [object CSSPrimitiveValue]
 
diff --git a/LayoutTests/svg/css/group-with-shadow.svg b/LayoutTests/svg/css/group-with-shadow.svg
index 00711de..13a72aa 100644
--- a/LayoutTests/svg/css/group-with-shadow.svg
+++ b/LayoutTests/svg/css/group-with-shadow.svg
@@ -4,7 +4,7 @@
 <svg version="1.1" baseProfile="basic" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="svg-root" width="100%" height="100%" viewBox="0 0 480 360">
 
 	<desc id="test-desc">Shadowy Group</desc>
-	<g id="test-body-content" transform="scale(2)" style="-webkit-shadow:5px 5px 5px grey">
+	<g id="test-body-content" transform="scale(2)" style="-webkit-svg-shadow:5px 5px 5px grey">
       <line x1="10" y1="10" x2="85" y2="10"
           style="stroke: purple;"/>
 
diff --git a/LayoutTests/svg/css/mask-with-shadow.svg b/LayoutTests/svg/css/mask-with-shadow.svg
index 8b784d7..755558d 100644
--- a/LayoutTests/svg/css/mask-with-shadow.svg
+++ b/LayoutTests/svg/css/mask-with-shadow.svg
@@ -17,7 +17,7 @@
 
         <rect id="masked" width="300" height="300" fill="url(#maskedGradient)" />
 
-        <mask id="mask_1" style="-webkit-shadow:5px 5px 5px grey">
+        <mask id="mask_1" style="-webkit-svg-shadow:5px 5px 5px grey">
             <circle cx="55" cy="55" r="50" fill="#ffffff" />
             <circle cx="55" cy="165" r="50" fill="#ffffff" />
             <circle cx="165" cy="55" r="50" fill="#ffffff" />
diff --git a/LayoutTests/svg/css/path-with-shadow.svg b/LayoutTests/svg/css/path-with-shadow.svg
index 0c678e5..282fb93 100644
--- a/LayoutTests/svg/css/path-with-shadow.svg
+++ b/LayoutTests/svg/css/path-with-shadow.svg
@@ -1,4 +1,4 @@
 <?xml version="1.0"?>
 <svg xmlns="http://www.w3.org/2000/svg">
-<path mask="url(#mask)" fill="blue" d="M 200 200 l 100 0 l 0 200 l -100 0 Z" style="-webkit-shadow: 5px 5px 5px grey"/>
+<path mask="url(#mask)" fill="blue" d="M 200 200 l 100 0 l 0 200 l -100 0 Z" style="-webkit-svg-shadow: 5px 5px 5px grey"/>
 </svg>
diff --git a/LayoutTests/svg/css/shadow-with-large-radius.svg b/LayoutTests/svg/css/shadow-with-large-radius.svg
index 83b709d..a717a56 100644
--- a/LayoutTests/svg/css/shadow-with-large-radius.svg
+++ b/LayoutTests/svg/css/shadow-with-large-radius.svg
@@ -1,3 +1,3 @@
 <svg xmlns="http://www.w3.org/2000/svg">
-<path d="M 100 100 L 200 100 L 200 200 L 100 200 Z" fill="#999" stroke="#000" stroke-width="10" style="-webkit-shadow: #f00 5px 5px 50px"></path>
+<path d="M 100 100 L 200 100 L 200 200 L 100 200 Z" fill="#999" stroke="#000" stroke-width="10" style="-webkit-svg-shadow: #f00 5px 5px 50px"></path>
 </svg>
diff --git a/LayoutTests/svg/css/shadow-with-negative-offset.svg b/LayoutTests/svg/css/shadow-with-negative-offset.svg
index cb5d6d8..9fe8e4d 100644
--- a/LayoutTests/svg/css/shadow-with-negative-offset.svg
+++ b/LayoutTests/svg/css/shadow-with-negative-offset.svg
@@ -1,3 +1,3 @@
 <svg xmlns="http://www.w3.org/2000/svg">
-<path d="M 100 100 L 200 100 L 200 200 L 100 200 Z" fill="#999" stroke="#000" stroke-width="10" style="-webkit-shadow: #f00 -5px -5px 50px"></path>
+<path d="M 100 100 L 200 100 L 200 200 L 100 200 Z" fill="#999" stroke="#000" stroke-width="10" style="-webkit-svg-shadow: #f00 -5px -5px 50px"></path>
 </svg>
diff --git a/LayoutTests/svg/css/stars-with-shadow.html b/LayoutTests/svg/css/stars-with-shadow.html
index 0d5ac58..ec821b5 100644
--- a/LayoutTests/svg/css/stars-with-shadow.html
+++ b/LayoutTests/svg/css/stars-with-shadow.html
@@ -63,7 +63,7 @@ window.addEventListener('load', function () {
 
 <style>
     #svg {
-        -webkit-shadow: 5px 5px 5px #888;
+        -webkit-svg-shadow: 5px 5px 5px #888;
     }
 </style>
 </head>
diff --git a/LayoutTests/svg/filters/shadow-on-filter.svg b/LayoutTests/svg/filters/shadow-on-filter.svg
index 255f10a..c0ba24a 100644
--- a/LayoutTests/svg/filters/shadow-on-filter.svg
+++ b/LayoutTests/svg/filters/shadow-on-filter.svg
@@ -1,10 +1,10 @@
 <svg xmlns="http://www.w3.org/2000/svg">
 <defs>
-<filter primitiveUnits="objectBoundingBox" id="filter" x="-50%" y="-50%" width="160%" height="160%" style="-webkit-shadow:10px 10px 3px purple;">
-<feFlood x="-40%" y="-40%" width="50%" height="50%" flood-color="red" style="-webkit-shadow:-4px -4px 0px blue;" result="flood1"/>
+<filter primitiveUnits="objectBoundingBox" id="filter" x="-50%" y="-50%" width="160%" height="160%" style="-webkit-svg-shadow:10px 10px 3px purple;">
+<feFlood x="-40%" y="-40%" width="50%" height="50%" flood-color="red" style="-webkit-svg-shadow:-4px -4px 0px blue;" result="flood1"/>
 <feFlood x="-20%" y="-20%" width="50%" height="50%" flood-color="green" result="flood2"/>
-<feComposite in="flood1" in2="flood2" width="120%" height="120%" result="comp1" style="-webkit-shadow:4px -1px 3px green;"/>
-<feGaussianBlur stdDeviation="4 4" style="-webkit-shadow: 6px 4px 8px yellow;"/>
+<feComposite in="flood1" in2="flood2" width="120%" height="120%" result="comp1" style="-webkit-svg-shadow:4px -1px 3px green;"/>
+<feGaussianBlur stdDeviation="4 4" style="-webkit-svg-shadow: 6px 4px 8px yellow;"/>
 </filter>
 </defs>
 <rect x="200" y="200" width="300" height="300" fill="green" style="filter:url(#filter);"/>
diff --git a/LayoutTests/svg/filters/shadow-on-rect-with-filter.svg b/LayoutTests/svg/filters/shadow-on-rect-with-filter.svg
index 1b97a36..5e49af8 100644
--- a/LayoutTests/svg/filters/shadow-on-rect-with-filter.svg
+++ b/LayoutTests/svg/filters/shadow-on-rect-with-filter.svg
@@ -7,5 +7,5 @@
 <feGaussianBlur stdDeviation="4 4" />
 </filter>
 </defs>
-<rect x="200" y="200" width="300" height="300" fill="green" style="filter:url(#filter);-webkit-shadow:-10px -10px 3px orange;"/>
+<rect x="200" y="200" width="300" height="300" fill="green" style="filter:url(#filter);-webkit-svg-shadow:-10px -10px 3px orange;"/>
 </svg>
diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index e08938f..16bb8a1 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,3 +1,23 @@
+2010-01-12  Beth Dakin  <bdakin at apple.com>
+
+        Rubber-stamped by Dave Hyatt.
+
+        This patch changes the name of -webkit-shadow to -webkit-svg-shadow 
+        to avoid giving a custom property an overly-general name.
+        <rdar://problem/7534590>
+
+        * css/CSSComputedStyleDeclaration.cpp:
+        (WebCore::):
+        * css/CSSParser.cpp:
+        (WebCore::CSSParser::parseShadow):
+        * css/SVGCSSComputedStyleDeclaration.cpp:
+        (WebCore::CSSComputedStyleDeclaration::getSVGPropertyCSSValue):
+        * css/SVGCSSParser.cpp:
+        (WebCore::CSSParser::parseSVGValue):
+        * css/SVGCSSPropertyNames.in:
+        * css/SVGCSSStyleSelector.cpp:
+        (WebCore::CSSStyleSelector::applySVGProperty):
+
 2010-01-12  Peter Kasting  <pkasting at google.com>
 
         Not reviewed, build fix.
diff --git a/WebCore/css/CSSComputedStyleDeclaration.cpp b/WebCore/css/CSSComputedStyleDeclaration.cpp
index 300299a..24b64d5 100644
--- a/WebCore/css/CSSComputedStyleDeclaration.cpp
+++ b/WebCore/css/CSSComputedStyleDeclaration.cpp
@@ -261,7 +261,7 @@ static const int computedProperties[] = {
     CSSPropertyWritingMode,
     CSSPropertyGlyphOrientationHorizontal,
     CSSPropertyGlyphOrientationVertical,
-    CSSPropertyWebkitShadow
+    CSSPropertyWebkitSvgShadow
 #endif
 };
 
diff --git a/WebCore/css/SVGCSSComputedStyleDeclaration.cpp b/WebCore/css/SVGCSSComputedStyleDeclaration.cpp
index 1f19983..f184b1b 100644
--- a/WebCore/css/SVGCSSComputedStyleDeclaration.cpp
+++ b/WebCore/css/SVGCSSComputedStyleDeclaration.cpp
@@ -166,7 +166,7 @@ PassRefPtr<CSSValue> CSSComputedStyleDeclaration::getSVGPropertyCSSValue(int pro
 
             return 0;
         }
-        case CSSPropertyWebkitShadow:
+        case CSSPropertyWebkitSvgShadow:
             return valueForShadow(svgStyle->shadow(), propertyID);
         case CSSPropertyMarker:
         case CSSPropertyEnableBackground:
diff --git a/WebCore/css/SVGCSSParser.cpp b/WebCore/css/SVGCSSParser.cpp
index 8730e49..0986f1c 100644
--- a/WebCore/css/SVGCSSParser.cpp
+++ b/WebCore/css/SVGCSSParser.cpp
@@ -257,7 +257,7 @@ bool CSSParser::parseSVGValue(int propId, bool important)
                 m_valueList->next();
         }
         break;
-    case CSSPropertyWebkitShadow:
+    case CSSPropertyWebkitSvgShadow:
         if (id == CSSValueNone)
             valid_primitive = true;
         else
diff --git a/WebCore/css/SVGCSSPropertyNames.in b/WebCore/css/SVGCSSPropertyNames.in
index 809eabe..9f97146 100644
--- a/WebCore/css/SVGCSSPropertyNames.in
+++ b/WebCore/css/SVGCSSPropertyNames.in
@@ -47,4 +47,4 @@ kerning
 text-anchor
 writing-mode
 
--webkit-shadow
+-webkit-svg-shadow
diff --git a/WebCore/css/CSSParser.cpp b/WebCore/css/CSSParser.cpp
index e71443c..6eb4e93 100644
--- a/WebCore/css/CSSParser.cpp
+++ b/WebCore/css/CSSParser.cpp
@@ -3770,8 +3770,8 @@ bool CSSParser::parseShadow(int propId, bool important)
                 // value.  Treat as invalid.
                 return false;
 #if ENABLE(SVG)
-            // -webkit-shadow does not support multiple values.
-            if (static_cast<CSSPropertyID>(propId) == CSSPropertyWebkitShadow)
+            // -webkit-svg-shadow does not support multiple values.
+            if (static_cast<CSSPropertyID>(propId) == CSSPropertyWebkitSvgShadow)
                 return false;
 #endif            
             // The value is good.  Commit it.
diff --git a/WebCore/css/SVGCSSStyleSelector.cpp b/WebCore/css/SVGCSSStyleSelector.cpp
index 6d131df..5ba7344 100644
--- a/WebCore/css/SVGCSSStyleSelector.cpp
+++ b/WebCore/css/SVGCSSStyleSelector.cpp
@@ -525,7 +525,7 @@ void CSSStyleSelector::applySVGProperty(int id, CSSValue* value)
             // Silently ignoring this property for now
             // http://bugs.webkit.org/show_bug.cgi?id=6022
             break;
-        case CSSPropertyWebkitShadow: {
+        case CSSPropertyWebkitSvgShadow: {
             if (isInherit)
                 return svgstyle->setShadow(m_parentStyle->svgStyle()->shadow() ? new ShadowData(*m_parentStyle->svgStyle()->shadow()) : 0);
             if (isInitial || primitiveValue) // initial | none
@@ -546,7 +546,7 @@ void CSSStyleSelector::applySVGProperty(int id, CSSValue* value)
             if (item->color)
                 color = getColorFromPrimitiveValue(item->color.get());
 
             // -webkit-shadow does should not have a spread or style
             ASSERT(!item->spread);
             ASSERT(!item->style);
                 
@@ -546,7 +546,7 @@ void CSSStyleSelector::applySVGProperty(int id, CSSValue* value)
                 color = getColorFromPrimitiveValue(item->color.get());
 
-            // -webkit-shadow does should not have a spread or style
+            // -webkit-svg-shadow does should not have a spread or style
             ASSERT(!item->spread);
             ASSERT(!item->style);

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list